@@ -114,6 +114,11 @@ class PageAttachment(models.Model):
         return u'page attachment: %s' % self.pk
 
 
+models.signals.pre_save.connect(
+        listeners.set_attachment_title,
+        sender=PageAttachment,
+        dispatch_uid='ccpages_set_attachment_title')
+
 models.signals.pre_save.connect(
         listeners.set_content_rendered,
         sender=Page,
